Runner

Struct Runner 

pub struct Runner<M: ProcessManager> { /* private fields */ }

Implementations

Source

impl<M: ProcessManager> Runner<M>

pub fn new(project: Project, pm: M, config: RunnerConfig) -> Self

pub async fn up(&mut self, services: Vec<String>) -> Result<Receiver<LogEvent>>

Starts the services defined in the project configuration.

Errors

Returns an error if any of the services fail to start.

pub async fn down(&mut self) -> Result<()>

Stops all services.

Errors

Returns an error if any of the services fail to stop.

pub async fn wait(&mut self) -> Result<()>

Waits for all services to exit.

Errors

Returns an error if any of the services fail to exit.